get_root_module

Function get_root_module 

pub fn get_root_module() -> Option<&'static str>
Retrieve profiled root module Get the root module name set during profiling initialization.

This is primarily used internally by the profiling macros.