ProfileType

Enum ProfileType 

pub enum ProfileType {
    Time,
    Memory,
    Both,
    None,
}
Types of profiling that can be performed.

This enum defines the different profiling modes available in the system. The profiling type determines what metrics are collected and reported.

Variants



Time

Time profiling only - measures wall clock/elapsed time



Memory

Memory profiling only - tracks memory allocations and deallocations



Both

Both time and memory profiling - combines both measurement types



None

No profiling - disables all profiling operations