pub fn init_verbosity(verbosity: Verbosity) -> Result<(), ThagCommonError>Expand description
Core profiling functionality and configuration. Initialize verbosity with a convenient function that handles common patterns.
Examples
use thag_common::{init_verbosity, V};
// Initialize with verbose for debugging
init_verbosity(V::V).expect("Failed to set verbosity");
// Initialize with debug
init_verbosity(V::D).expect("Failed to set verbosity");Errors
Returns an error if the global verbosity cannot be set.