pub fn prompted_analysis(
file_path_str: &str,
profile_type: ProfileType,
analysis_type: AnalysisType,
)Expand description
Run prompted analysis for profiling visualization
This function provides an interactive prompt to the user asking if they want to generate and view a profiling visualization. It handles the async execution of the interactive prompt and error handling.
Arguments
demo_name- Name of the demo being profiledprofile_type- Type of profiling (Time or Memory)analysis_type- Type of analysis visualization to generate